repetition.hpp

The repetition.hpp includes the headers in the repetition folder.

#### Usage

#include <boost/preprocessor/repetition.hpp>

#### Includes

- <boost/preprocessor/repetition/deduce_r.hpp>
- <boost/preprocessor/repetition/deduce_z.hpp>
- <boost/preprocessor/repetition/enum.hpp>
- <boost/preprocessor/repetition/enum_binary_params.hpp>
- <boost/preprocessor/repetition/enum_params.hpp>
- <boost/preprocessor/repetition/enum_params_with_a_default.hpp>
- <boost/preprocessor/repetition/enum_params_with_defaults.hpp>
- <boost/preprocessor/repetition/enum_shifted_params.hpp>
- <boost/preprocessor/repetition/enum_shifted.hpp>
- <boost/preprocessor/repetition/enum_trailing.hpp>
- <boost/preprocessor/repetition/enum_trailing_binary_params.hpp>
- <boost/preprocessor/repetition/enum_trailing_params.hpp>
- <boost/preprocessor/repetition/for.hpp>
- <boost/preprocessor/repetition/repeat.hpp>
- <boost/preprocessor/repetition/repeat_from_to.hpp>

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)